.. image:: https://img.shields.io/pypi/v/striebel.bib
   :alt: PyPI
   :target: https://pypi.org/project/striebel.bib

.. image:: https://static.pepy.tech/badge/striebel.bib
   :alt: Downloads
   :target: https://pepy.tech/project/striebel.bib

.. image:: https://img.shields.io/github/license/striebel/striebel.bib
   :alt: License
   :target: https://github.com/striebel/striebel.bib/blob/master/LICENSE 

.. image:: https://img.shields.io/badge/python_3-gray
   :alt: Python 3
   :target: https://docs.python.org/3/

.. image:: https://img.shields.io/badge/linux-gray
   :alt: Linux
   :target: https://kernel.org/

The ``python-project-stub`` codebase provides stub files that
can be used to create a Python project that is able to
be packaged and uploaded to the Python Package Index
and hence can be conveniently installed with

.. code-block:: sh
   
   pip install my-project-name
   
The ``Makefile`` provided in the codebase has targets for
building, uploading,
downloading, installing, and executing the package.

Project links
-------------

* Repo: `https://github.com/striebel/striebel.bib
  <https://github.com/striebel/striebel.bib>`_
* PyPI: `https://pypi.org/project/striebel.bib
  <https://pypi.org/project/striebel.bib>`_
* Docs: `https://striebel.github.io/striebel.bib
  <https://striebel.github.io/striebel.bib>`_
